Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/mono.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/mcs/class
diff options
context:
space:
mode:
authorMaher Jendoubi <maher.jendoubi@gmail.com>2020-01-25 21:55:22 +0300
committerAlexander Köplinger <alex.koeplinger@outlook.com>2020-01-25 21:55:22 +0300
commit4704c85c9db3fb1dccd9191bec4b349180a193ee (patch)
tree17982d97f3edde27890888adc035f8dca918bbca /mcs/class
parent9fc4cae8759da737baa66093b6cbf8cb3da1e124 (diff)
Fix typos (#18585)
* Contributing: fix typos * fixed encoding and other typos * fixed encoding and spotted other typos * Update TransformationRules.cs
Diffstat (limited to 'mcs/class')
-rw-r--r--mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/ContractReference.xml2
-rw-r--r--mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/DiscoveryDocument.xml2
-rw-r--r--mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/DiscoveryDocumentReference.xml2
-rw-r--r--mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/SchemaReference.xml2
-rw-r--r--mcs/class/referencesource/System.Data.Entity/System/Data/Mapping/ViewGeneration/Validation/ForeignConstraint.cs2
-rw-r--r--mcs/class/referencesource/System.Data.Entity/System/Data/Query/PlanCompiler/TransformationRules.cs66
-rw-r--r--mcs/class/referencesource/System.Data/System/Data/Common/DBConnectionString.cs2
-rw-r--r--mcs/class/referencesource/System.Data/System/Data/Odbc/odbcmetadatafactory.cs10
-rw-r--r--mcs/class/referencesource/System.Data/System/Data/OleDb/OleDbMetaDataFactory.cs8
-rw-r--r--mcs/class/referencesource/System.Data/System/Data/OleDb/oledbconnectionstring.cs2
-rw-r--r--mcs/class/referencesource/System.Data/System/Data/SqlClient/sqlmetadatafactory.cs2
-rw-r--r--mcs/class/referencesource/System.Web.DataVisualization/Common/ChartTypes/BoxPlotChart.cs32
-rw-r--r--mcs/class/referencesource/System.Web.DataVisualization/Common/ChartTypes/ErrorBarChart.cs34
-rw-r--r--mcs/class/referencesource/System/net/System/Net/WebRequestMethods.cs2
14 files changed, 84 insertions, 84 deletions
diff --git a/mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/ContractReference.xml b/mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/ContractReference.xml
index 085775ad206..6723880da05 100644
--- a/mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/ContractReference.xml
+++ b/mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/ContractReference.xml
@@ -21,7 +21,7 @@
<Docs>
<remarks>
<attribution license="cc4" from="Microsoft" modified="false" />
- <para>XML Web services discovery involves discovering the available Web Services given an URL. The URL usually points to a discovery document, which typically has a.disco file name extension. Within a discovery document are references to information about the existance of XML Web services. These references can refer to service descriptions, XML Schema Definition language (XSD) schemas or other discovery documents. This class represents a reference to a Service Description.</para>
+ <para>XML Web services discovery involves discovering the available Web Services given an URL. The URL usually points to a discovery document, which typically has a.disco file name extension. Within a discovery document are references to information about the existence of XML Web services. These references can refer to service descriptions, XML Schema Definition language (XSD) schemas or other discovery documents. This class represents a reference to a Service Description.</para>
<para>Within a discovery document, a reference to a Service Description is contained within a contractRef XML element. The contractRef XML element has two attributes: ref and docRef. The contractRef element must have an XML namespace matching the <see cref="F:System.Web.Services.Discovery.ContractReference.Namespace" /> constant, whereas the ref and docRef attributes are placed in the <see cref="P:System.Web.Services.Discovery.ContractReference.Ref" /> and <see cref="P:System.Web.Services.Discovery.ContractReference.DocRef" /> properties.</para>
</remarks>
<summary>
diff --git a/mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/DiscoveryDocument.xml b/mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/DiscoveryDocument.xml
index b76e04d18cd..c216e91af84 100644
--- a/mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/DiscoveryDocument.xml
+++ b/mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/DiscoveryDocument.xml
@@ -21,7 +21,7 @@
<Docs>
<remarks>
<attribution license="cc4" from="Microsoft" modified="false" />
- <para>XML Web services discovery involves discovering the available XML Web services, given an URL. The URL typically points to a discovery document, which usually has a.disco file name extension. The discovery document, which is an XML document, contains references to information about the existance of XML Web services, such as a service description, XML Schema Definition (XSD) language schema, or another discovery document. This class represents the contents of the discovery document; where the <see cref="P:System.Web.Services.Discovery.DiscoveryDocument.References" /> property contains a list of the references contained within the discovery document.</para>
+ <para>XML Web services discovery involves discovering the available XML Web services, given an URL. The URL typically points to a discovery document, which usually has a.disco file name extension. The discovery document, which is an XML document, contains references to information about the existence of XML Web services, such as a service description, XML Schema Definition (XSD) language schema, or another discovery document. This class represents the contents of the discovery document; where the <see cref="P:System.Web.Services.Discovery.DiscoveryDocument.References" /> property contains a list of the references contained within the discovery document.</para>
</remarks>
<summary>
<attribution license="cc4" from="Microsoft" modified="false" />
diff --git a/mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/DiscoveryDocumentReference.xml b/mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/DiscoveryDocumentReference.xml
index c756e7a0290..425c3cc40cb 100644
--- a/mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/DiscoveryDocumentReference.xml
+++ b/mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/DiscoveryDocumentReference.xml
@@ -21,7 +21,7 @@
<Docs>
<remarks>
<attribution license="cc4" from="Microsoft" modified="false" />
- <para>XML Web services discovery involves discovering the available XML Web services given an URL. The URL typically points to a discovery document, which usually has a.disco file name extension. The discovery document contains references to information about the existance of XML Web services, such as Service Descriptions, XML Schema Definition language (XSD) schemas, or other discovery documents. This class represents a reference to a discovery document.</para>
+ <para>XML Web services discovery involves discovering the available XML Web services given an URL. The URL typically points to a discovery document, which usually has a.disco file name extension. The discovery document contains references to information about the existence of XML Web services, such as Service Descriptions, XML Schema Definition language (XSD) schemas, or other discovery documents. This class represents a reference to a discovery document.</para>
</remarks>
<summary>
<attribution license="cc4" from="Microsoft" modified="false" />
diff --git a/mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/SchemaReference.xml b/mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/SchemaReference.xml
index 2207fba3405..35da42d8a2e 100644
--- a/mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/SchemaReference.xml
+++ b/mcs/class/System.Web.Services/Documentation/en/System.Web.Services.Discovery/SchemaReference.xml
@@ -21,7 +21,7 @@
<Docs>
<remarks>
<attribution license="cc4" from="Microsoft" modified="false" />
- <para>XML Web services discovery involves discovering the available XML Web services given, a URL. A The URL typically points to a discovery document, which usually has a.disco file name extension. The discovery document contains references to information about the existance of XML Web services. These references can refer to service descriptions, XSD schemas, or other discovery documents. This class represents a reference to an XSD schema.</para>
+ <para>XML Web services discovery involves discovering the available XML Web services given, a URL. A The URL typically points to a discovery document, which usually has a.disco file name extension. The discovery document contains references to information about the existence of XML Web services. These references can refer to service descriptions, XSD schemas, or other discovery documents. This class represents a reference to an XSD schema.</para>
<para>Within a discovery document, a reference to an XSD schema is contained within a schemaRef XML element. The schemaRef XML element has an XML namespace and a ref attribute. The value of the XML namespace must match the <see cref="F:System.Web.Services.Discovery.SchemaReference.Namespace" /> constant. The value of the ref attribute is placed in the <see cref="P:System.Web.Services.Discovery.SchemaReference.Ref" /> property.</para>
</remarks>
<summary>
diff --git a/mcs/class/referencesource/System.Data.Entity/System/Data/Mapping/ViewGeneration/Validation/ForeignConstraint.cs b/mcs/class/referencesource/System.Data.Entity/System/Data/Mapping/ViewGeneration/Validation/ForeignConstraint.cs
index 28c9c71a945..40df1fb705f 100644
--- a/mcs/class/referencesource/System.Data.Entity/System/Data/Mapping/ViewGeneration/Validation/ForeignConstraint.cs
+++ b/mcs/class/referencesource/System.Data.Entity/System/Data/Mapping/ViewGeneration/Validation/ForeignConstraint.cs
@@ -379,7 +379,7 @@ namespace System.Data.Mapping.ViewGeneration.Validation
//We need to check to see if the dependent properties that were mapped from S side are present as
//dependant properties of this ref constraint on the Edm side. We need to do the same for principal side but
//we can not enforce equality since the order of the properties participating in the constraint on the S side and
- //C side could be different. This is OK as long as they are mapped appropriately. We also can not use Existance as a sufficient
+ //C side could be different. This is OK as long as they are mapped appropriately. We also can not use Existence as a sufficient
//condition since it will allow invalid mapping where FK columns could have been flipped when mapping to the Edm side. So
//we make sure that the index of the properties in the principal and dependant are same on the Edm side even if they are in
//different order for ref constraints for Edm and store side.
diff --git a/mcs/class/referencesource/System.Data/System/Data/Common/DBConnectionString.cs b/mcs/class/referencesource/System.Data/System/Data/Common/DBConnectionString.cs
index 6085d61c98c..db94d80e753 100644
--- a/mcs/class/referencesource/System.Data/System/Data/Common/DBConnectionString.cs
+++ b/mcs/class/referencesource/System.Data/System/Data/Common/DBConnectionString.cs
@@ -42,7 +42,7 @@ namespace System.Data.Common {
// a linked list of key/value and their length in _encryptedUsersConnectionString
readonly private NameValuePair _keychain;
- // track the existance of "password" or "pwd" in the connection string
+ // track the existence of "password" or "pwd" in the connection string
// not used for anything anymore but must keep it set correct for V1.1 serialization
readonly private bool _hasPassword;
diff --git a/mcs/class/referencesource/System.Data/System/Data/Odbc/odbcmetadatafactory.cs b/mcs/class/referencesource/System.Data/System/Data/Odbc/odbcmetadatafactory.cs
index 01ffbf81c00..9e313dbdc02 100644
--- a/mcs/class/referencesource/System.Data/System/Data/Odbc/odbcmetadatafactory.cs
+++ b/mcs/class/referencesource/System.Data/System/Data/Odbc/odbcmetadatafactory.cs
@@ -60,7 +60,7 @@ namespace System.Data.Odbc{
new SchemaFunctionName(OdbcMetaDataCollectionNames.Tables,ODBC32.SQL_API.SQLTABLES),
new SchemaFunctionName(OdbcMetaDataCollectionNames.Views,ODBC32.SQL_API.SQLTABLES)};
- // verify the existance of the table in the data set
+ // verify the existence of the table in the data set
DataTable metaDataCollectionsTable = CollectionDataSet.Tables[DbMetaDataCollectionNames.MetaDataCollections];
if (metaDataCollectionsTable == null){
throw ADP.UnableToBuildCollection(DbMetaDataCollectionNames.MetaDataCollections);
@@ -69,7 +69,7 @@ namespace System.Data.Odbc{
// copy the table filtering out any rows that don't apply to the current version of the provider
metaDataCollectionsTable = CloneAndFilterCollection(DbMetaDataCollectionNames.MetaDataCollections, null);
- // verify the existance of the table in the data set
+ // verify the existence of the table in the data set
DataTable restrictionsTable = CollectionDataSet.Tables[DbMetaDataCollectionNames.Restrictions];
if (restrictionsTable != null){
// copy the table filtering out any rows that don't apply to the current version of the provider
@@ -747,7 +747,7 @@ namespace System.Data.Odbc{
- // verify the existance of the table in the data set
+ // verify the existence of the table in the data set
DataTable dataTypesTable = CollectionDataSet.Tables[DbMetaDataCollectionNames.DataTypes];
if (dataTypesTable == null){
throw ADP.UnableToBuildCollection(DbMetaDataCollectionNames.DataTypes);
@@ -927,13 +927,13 @@ namespace System.Data.Odbc{
throw ADP.TooManyRestrictions(DbMetaDataCollectionNames.ReservedWords);
}
- // verify the existance of the table in the data set
+ // verify the existence of the table in the data set
DataTable reservedWordsTable = CollectionDataSet.Tables[DbMetaDataCollectionNames.ReservedWords];
if (reservedWordsTable == null){
throw ADP.UnableToBuildCollection(DbMetaDataCollectionNames.ReservedWords);
}
- // copy the table filtering out any rows that don't apply to tho current version of the prrovider
+ // copy the table filtering out any rows that don't apply to tho current version of the provider
reservedWordsTable = CloneAndFilterCollection(DbMetaDataCollectionNames.ReservedWords, null);
DataColumn reservedWordColumn = reservedWordsTable.Columns[DbMetaDataColumnNames.ReservedWord];
diff --git a/mcs/class/referencesource/System.Data/System/Data/OleDb/OleDbMetaDataFactory.cs b/mcs/class/referencesource/System.Data/System/Data/OleDb/OleDbMetaDataFactory.cs
index 7189c9f86b4..8a791591827 100644
--- a/mcs/class/referencesource/System.Data/System/Data/OleDb/OleDbMetaDataFactory.cs
+++ b/mcs/class/referencesource/System.Data/System/Data/OleDb/OleDbMetaDataFactory.cs
@@ -61,7 +61,7 @@ namespace System.Data.OleDb{
new SchemaRowsetName(OleDbMetaDataCollectionNames.Tables,OleDbSchemaGuid.Tables),
new SchemaRowsetName(OleDbMetaDataCollectionNames.Views,OleDbSchemaGuid.Views)};
- // verify the existance of the table in the data set
+ // verify the existence of the table in the data set
DataTable metaDataCollectionsTable = CollectionDataSet.Tables[DbMetaDataCollectionNames.MetaDataCollections];
if (metaDataCollectionsTable == null){
throw ADP.UnableToBuildCollection(DbMetaDataCollectionNames.MetaDataCollections);
@@ -70,7 +70,7 @@ namespace System.Data.OleDb{
// copy the table filtering out any rows that don't apply to the current version of the provider
metaDataCollectionsTable = CloneAndFilterCollection(DbMetaDataCollectionNames.MetaDataCollections, null);
- // verify the existance of the table in the data set
+ // verify the existence of the table in the data set
DataTable restrictionsTable = CollectionDataSet.Tables[DbMetaDataCollectionNames.Restrictions];
if (restrictionsTable != null){
// copy the table filtering out any rows that don't apply to the current version of the provider
@@ -333,7 +333,7 @@ namespace System.Data.OleDb{
private DataTable GetDataTypesTable(OleDbConnection connection){
- // verify the existance of the table in the data set
+ // verify the existence of the table in the data set
DataTable dataTypesTable = CollectionDataSet.Tables[DbMetaDataCollectionNames.DataTypes];
if (dataTypesTable == null){
throw ADP.UnableToBuildCollection(DbMetaDataCollectionNames.DataTypes);
@@ -453,7 +453,7 @@ namespace System.Data.OleDb{
private DataTable GetReservedWordsTable(OleDbConnectionInternal internalConnection){
- // verify the existance of the table in the data set
+ // verify the existence of the table in the data set
DataTable reservedWordsTable = CollectionDataSet.Tables[DbMetaDataCollectionNames.ReservedWords];
if (null == reservedWordsTable){
throw ADP.UnableToBuildCollection(DbMetaDataCollectionNames.ReservedWords);
diff --git a/mcs/class/referencesource/System.Data/System/Data/OleDb/oledbconnectionstring.cs b/mcs/class/referencesource/System.Data/System/Data/OleDb/oledbconnectionstring.cs
index e1406cfc2a1..f7d617d69d2 100644
--- a/mcs/class/referencesource/System.Data/System/Data/OleDb/oledbconnectionstring.cs
+++ b/mcs/class/referencesource/System.Data/System/Data/OleDb/oledbconnectionstring.cs
@@ -194,7 +194,7 @@ namespace System.Data.OleDb {
if (!_hasSupportIRow) {
object value = command.GetPropertyValue(OleDbPropertySetGuid.Rowset, ODB.DBPROP_IRow);
- // SQLOLEDB always returns VARIANT_FALSE for DBPROP_IROW, so base the answer on existance
+ // SQLOLEDB always returns VARIANT_FALSE for DBPROP_IROW, so base the answer on existence
supportIRow = !(value is OleDbPropertyStatus);
_supportIRow = supportIRow;
_hasSupportIRow = true;
diff --git a/mcs/class/referencesource/System.Data/System/Data/SqlClient/sqlmetadatafactory.cs b/mcs/class/referencesource/System.Data/System/Data/SqlClient/sqlmetadatafactory.cs
index f17f069a00f..f0cf05b34d9 100644
--- a/mcs/class/referencesource/System.Data/System/Data/SqlClient/sqlmetadatafactory.cs
+++ b/mcs/class/referencesource/System.Data/System/Data/SqlClient/sqlmetadatafactory.cs
@@ -242,7 +242,7 @@ namespace System.Data.SqlClient{
private DataTable GetDataTypesTable(SqlConnection connection){
- // verify the existance of the table in the data set
+ // verify the existence of the table in the data set
DataTable dataTypesTable = CollectionDataSet.Tables[DbMetaDataCollectionNames.DataTypes];
if (dataTypesTable == null){
throw ADP.UnableToBuildCollection(DbMetaDataCollectionNames.DataTypes);
diff --git a/mcs/class/referencesource/System.Web.DataVisualization/Common/ChartTypes/BoxPlotChart.cs b/mcs/class/referencesource/System.Web.DataVisualization/Common/ChartTypes/BoxPlotChart.cs
index e1b650d3c6e..398215a4d3e 100644
--- a/mcs/class/referencesource/System.Web.DataVisualization/Common/ChartTypes/BoxPlotChart.cs
+++ b/mcs/class/referencesource/System.Web.DataVisualization/Common/ChartTypes/BoxPlotChart.cs
@@ -1,6 +1,6 @@
//-------------------------------------------------------------
-// <copyright company=’Microsoft Corporation’>
-// Copyright © Microsoft Corporation. All Rights Reserved.
+// <copyright company=’Microsoft Corporation’>
+// Copyright © Microsoft Corporation. All Rights Reserved.
// </copyright>
//-------------------------------------------------------------
// @owner=alexgor, deliant
@@ -161,7 +161,7 @@ namespace System.Web.UI.DataVisualization.Charting.ChartTypes
virtual public bool ZeroCrossing { get{ return false;} }
/// <summary>
- /// True if palette colors should be applied for each data paoint.
+ /// True if palette colors should be applied for each data point.
/// Otherwise the color is applied to the series.
/// </summary>
virtual public bool ApplyPaletteColorsToPoints { get { return false; } }
@@ -351,7 +351,7 @@ namespace System.Web.UI.DataVisualization.Charting.ChartTypes
double yValue1 = vAxis.GetLogValue( point.YValues[1] );
xValue = hAxis.GetLogValue(xValue);
- // Check if chart is completly out of the data scaleView
+ // Check if chart is completely out of the data scaleView
if(xValue < hAxis.ViewMinimum ||
xValue > hAxis.ViewMaximum ||
(yValue0 < vAxis.ViewMinimum && yValue1 < vAxis.ViewMinimum) ||
@@ -386,13 +386,13 @@ namespace System.Web.UI.DataVisualization.Charting.ChartTypes
}
low = vAxis.GetLinearPosition(low);
- // Remeber pre-calculated point position
+ // Remember pre-calculated point position
point.positionRel = new PointF((float)xPosition, (float)Math.Min(high, low));
if( common.ProcessModePaint )
{
- // Check if chart is partialy in the data scaleView
+ // Check if chart is partially in the data scaleView
bool clipRegionSet = false;
if(xValue == hAxis.ViewMinimum || xValue == hAxis.ViewMaximum )
{
@@ -613,7 +613,7 @@ namespace System.Web.UI.DataVisualization.Charting.ChartTypes
double yValue1 = vAxis.GetLogValue( point.YValues[1] );
xValue = hAxis.GetLogValue(xValue);
- // Check if chart is completly out of the data scaleView
+ // Check if chart is completely out of the data scaleView
if(xValue < hAxis.ViewMinimum ||
xValue > hAxis.ViewMaximum ||
(yValue0 < vAxis.ViewMinimum && yValue1 < vAxis.ViewMinimum) ||
@@ -908,7 +908,7 @@ namespace System.Web.UI.DataVisualization.Charting.ChartTypes
text = point.ReplaceKeywords(point.Label);
}
- // Adjust label positio to the marker size
+ // Adjust label position to the marker size
SizeF markerSizes = new SizeF(0f, 0f);
if (point.MarkerStyle != MarkerStyle.None)
{
@@ -1131,7 +1131,7 @@ namespace System.Web.UI.DataVisualization.Charting.ChartTypes
double yValue1 = vAxis.GetLogValue( point.YValues[1] );
xValue = hAxis.GetLogValue(xValue);
- // Check if chart is completly out of the data scaleView
+ // Check if chart is completely out of the data scaleView
if(xValue < hAxis.ViewMinimum ||
xValue > hAxis.ViewMaximum ||
(yValue0 < vAxis.ViewMinimum && yValue1 < vAxis.ViewMinimum) ||
@@ -1165,7 +1165,7 @@ namespace System.Web.UI.DataVisualization.Charting.ChartTypes
}
low = vAxis.GetLinearPosition(low);
- // Remeber pre-calculated point position
+ // Remember pre-calculated point position
point.positionRel = new PointF((float)xPosition, (float)Math.Min(high, low));
// 3D Transform coordinates
@@ -1180,7 +1180,7 @@ namespace System.Web.UI.DataVisualization.Charting.ChartTypes
if( common.ProcessModePaint )
{
- // Check if chart is partialy in the data scaleView
+ // Check if chart is partially in the data scaleView
bool clipRegionSet = false;
if(xValue == hAxis.ViewMinimum || xValue == hAxis.ViewMaximum )
{
@@ -1402,7 +1402,7 @@ namespace System.Web.UI.DataVisualization.Charting.ChartTypes
double yValue1 = vAxis.GetLogValue( point.YValues[1] );
xValue = hAxis.GetLogValue(xValue);
- // Check if chart is completly out of the data scaleView
+ // Check if chart is completely out of the data scaleView
if(xValue < hAxis.ViewMinimum ||
xValue > hAxis.ViewMaximum ||
(yValue0 < vAxis.ViewMinimum && yValue1 < vAxis.ViewMinimum) ||
@@ -1521,7 +1521,7 @@ namespace System.Web.UI.DataVisualization.Charting.ChartTypes
/// </summary>
/// <param name="common">Chart common elements.</param>
/// <param name="area">Chart area the series belongs to.</param>
- /// <param name="series">Sereis of the point.</param>
+ /// <param name="series">Series of the point.</param>
/// <param name="point">Point object.</param>
/// <param name="pointIndex">Index of the point.</param>
/// <param name="yValueIndex">Index of the Y value to get.</param>
@@ -1589,7 +1589,7 @@ namespace System.Web.UI.DataVisualization.Charting.ChartTypes
Chart control = boxPlotSeries.Chart;
if(control != null)
{
- // Get linked series and check existance
+ // Get linked series and check existence
if(control.Series.IndexOf(linkedSeriesName) == -1)
{
throw(new InvalidOperationException(SR.ExceptionCustomAttributeSeriesNameNotFound("BoxPlotSeries", linkedSeriesName) ));
@@ -1692,7 +1692,7 @@ namespace System.Web.UI.DataVisualization.Charting.ChartTypes
requiredPercentile[1] = 100.0 - requiredPercentile[0];
}
- // Calculate 5 recured percentile values
+ // Calculate 5 recurred percentile values
double[] percentileValues = CalculatePercentileValues(yValues, requiredPercentile);
// Set data points values
@@ -1753,7 +1753,7 @@ namespace System.Web.UI.DataVisualization.Charting.ChartTypes
// Update point's values
if(unusualValuesList.Count > 0)
{
- // Create new arry of values for the data pont
+ // Create new array of values for the data pont
double[] newYValues = new double[6 + unusualValuesList.Count];
// Copy original data
diff --git a/mcs/class/referencesource/System.Web.DataVisualization/Common/ChartTypes/ErrorBarChart.cs b/mcs/class/referencesource/System.Web.DataVisualization/Common/ChartTypes/ErrorBarChart.cs
index 77f6d6ebce5..4494199f421 100644
--- a/mcs/class/referencesource/System.Web.DataVisualization/Common/ChartTypes/ErrorBarChart.cs
+++ b/mcs/class/referencesource/System.Web.DataVisualization/Common/ChartTypes/ErrorBarChart.cs
@@ -1,6 +1,6 @@
//-------------------------------------------------------------
-// <copyright company=’Microsoft Corporation’>
-// Copyright © Microsoft Corporation. All Rights Reserved.
+// <copyright company=’Microsoft Corporation’>
+// Copyright © Microsoft Corporation. All Rights Reserved.
// </copyright>
//-------------------------------------------------------------
// @owner=alexgor, deliant
@@ -209,7 +209,7 @@ using System.Collections.Generic;
virtual public bool ZeroCrossing { get{ return false;} }
/// <summary>
- /// True if palette colors should be applied for each data paoint.
+ /// True if palette colors should be applied for each data point.
/// Otherwise the color is applied to the series.
/// </summary>
virtual public bool ApplyPaletteColorsToPoints { get { return false; } }
@@ -479,7 +479,7 @@ using System.Collections.Generic;
double yValue1 = vAxis.GetLogValue( point.YValues[2] );
xValue = hAxis.GetLogValue(xValue);
- // Check if chart is completly out of the data scaleView
+ // Check if chart is completely out of the data scaleView
if(xValue < hAxis.ViewMinimum ||
xValue > hAxis.ViewMaximum ||
(yValue0 < vAxis.ViewMinimum && yValue1 < vAxis.ViewMinimum) ||
@@ -546,13 +546,13 @@ using System.Collections.Generic;
}
low = vAxis.GetLinearPosition(low);
- // Remeber pre-calculated point position
+ // Remember pre-calculated point position
point.positionRel = new PointF((float)xPosition, (float)Math.Min(high, low));
if( common.ProcessModePaint )
{
- // Check if chart is partialy in the data scaleView
+ // Check if chart is partially in the data scaleView
bool clipRegionSet = false;
if(xValue == hAxis.ViewMinimum || xValue == hAxis.ViewMaximum )
{
@@ -631,7 +631,7 @@ using System.Collections.Generic;
double yValue1 = vAxis.GetLogValue( point.YValues[2] );
xValue = hAxis.GetLogValue(xValue);
- // Check if chart is completly out of the data scaleView
+ // Check if chart is completely out of the data scaleView
if(xValue < hAxis.ViewMinimum ||
xValue > hAxis.ViewMaximum ||
(yValue0 < vAxis.ViewMinimum && yValue1 < vAxis.ViewMinimum) ||
@@ -965,7 +965,7 @@ using System.Collections.Generic;
text = point.ReplaceKeywords(point.Label);
}
- // Adjust label positio to the marker size
+ // Adjust label position to the marker size
SizeF markerSizes = new SizeF(0f, 0f);
if (point.MarkerStyle != MarkerStyle.None)
{
@@ -1232,7 +1232,7 @@ using System.Collections.Generic;
double yValue1 = vAxis.GetLogValue( point.YValues[2] );
xValue = hAxis.GetLogValue(xValue);
- // Check if chart is completly out of the data scaleView
+ // Check if chart is completely out of the data scaleView
if(xValue < hAxis.ViewMinimum ||
xValue > hAxis.ViewMaximum ||
(yValue0 < vAxis.ViewMinimum && yValue1 < vAxis.ViewMinimum) ||
@@ -1297,7 +1297,7 @@ using System.Collections.Generic;
}
low = vAxis.GetLinearPosition(low);
- // Remeber pre-calculated point position
+ // Remember pre-calculated point position
point.positionRel = new PointF((float)xPosition, (float)Math.Min(high, low));
// 3D Transform coordinates
@@ -1309,7 +1309,7 @@ using System.Collections.Generic;
if( common.ProcessModePaint )
{
- // Check if chart is partialy in the data scaleView
+ // Check if chart is partially in the data scaleView
bool clipRegionSet = false;
if(xValue == hAxis.ViewMinimum || xValue == hAxis.ViewMaximum )
{
@@ -1401,7 +1401,7 @@ using System.Collections.Generic;
double yValue1 = vAxis.GetLogValue( point.YValues[2] );
xValue = hAxis.GetLogValue(xValue);
- // Check if chart is completly out of the data scaleView
+ // Check if chart is completely out of the data scaleView
if(xValue < hAxis.ViewMinimum ||
xValue > hAxis.ViewMaximum ||
(yValue0 < vAxis.ViewMinimum && yValue1 < vAxis.ViewMinimum) ||
@@ -1576,7 +1576,7 @@ using System.Collections.Generic;
/// </summary>
/// <param name="common">Chart common elements.</param>
/// <param name="area">Chart area the series belongs to.</param>
- /// <param name="series">Sereis of the point.</param>
+ /// <param name="series">Series of the point.</param>
/// <param name="point">Point object.</param>
/// <param name="pointIndex">Index of the point.</param>
/// <param name="yValueIndex">Index of the Y value to get.</param>
@@ -1615,7 +1615,7 @@ using System.Collections.Generic;
return;
}
- // Parase the value of the ErrorBarType attribute.
+ // Parse the value of the ErrorBarType attribute.
double param = double.NaN;
ErrorBarType errorBarType = ErrorBarType.StandardError;
if(errorBarSeries.IsCustomPropertySet(CustomPropertyName.ErrorBarType))
@@ -1681,7 +1681,7 @@ using System.Collections.Generic;
}
}
- // Number of poist without empty points
+ // Number of point without empty points
pointNumber -= numberOfEmptyPoints;
if (double.IsNaN(param))
@@ -1823,7 +1823,7 @@ using System.Collections.Generic;
Chart control = errorBarSeries.Chart;
if(control != null)
{
- // Get linked series and check existance
+ // Get linked series and check existence
if(control.Series.IndexOf(linkedSeriesName) == -1)
{
throw (new InvalidOperationException(SR.ExceptionDataSeriesNameNotFound(linkedSeriesName)));
@@ -1834,7 +1834,7 @@ using System.Collections.Generic;
errorBarSeries.XAxisType = linkedSeries.XAxisType;
errorBarSeries.YAxisType = linkedSeries.YAxisType;
- // Get cennter values from the linked series
+ // Get center values from the linked series
errorBarSeries.Points.Clear();
foreach(DataPoint point in linkedSeries.Points)
{
diff --git a/mcs/class/referencesource/System/net/System/Net/WebRequestMethods.cs b/mcs/class/referencesource/System/net/System/Net/WebRequestMethods.cs
index 7ffedbd56e2..505b6f76e26 100644
--- a/mcs/class/referencesource/System/net/System/Net/WebRequestMethods.cs
+++ b/mcs/class/referencesource/System/net/System/Net/WebRequestMethods.cs
@@ -7,7 +7,7 @@ namespace System.Net {
public const string UploadFile = "STOR"; // uploads a file
public const string DeleteFile = "DELE"; // deletes a file
public const string AppendFile = "APPE"; // append a file
- public const string GetFileSize = "SIZE"; // determines if a file is in existance
+ public const string GetFileSize = "SIZE"; // determines if a file is in existence
public const string UploadFileWithUniqueName = "STOU";
public const string MakeDirectory = "MKD";
public const string RemoveDirectory = "RMD";
diff --git a/mcs/class/referencesource/System.Data.Entity/System/Data/Query/PlanCompiler/TransformationRules.cs b/mcs/class/referencesource/System.Data.Entity/System/Data/Query/PlanCompiler/TransformationRules.cs
index 947bb1ef397..ed3e6adb335 100644
--- a/mcs/class/referencesource/System.Data.Entity/System/Data/Query/PlanCompiler/TransformationRules.cs
+++ b/mcs/class/referencesource/System.Data.Entity/System/Data/Query/PlanCompiler/TransformationRules.cs
@@ -41,7 +41,7 @@ namespace System.Data.Query.PlanCompiler
/// Whether any rule was applied that may have caused modifications such that projection pruning
/// may be useful
/// </summary>
- internal bool ProjectionPrunningRequired { get { return this.m_projectionPrunningRequired; } }
+ internal bool ProjectionPruningRequired { get { return this.m_projectionPruningRequired; } }
/// <summary>
/// Whether any rule was applied that may have caused modifications such that reapplying
@@ -50,7 +50,7 @@ namespace System.Data.Query.PlanCompiler
internal bool ReapplyNullabilityRules { get { return this.m_reapplyNullabilityRules; } }
/// <summary>
- /// Remap the given subree using the current remapper
+ /// Remap the given subtree using the current remapper
/// </summary>
/// <param name="subTree"></param>
internal void RemapSubtree(Node subTree)
@@ -285,7 +285,7 @@ namespace System.Data.Query.PlanCompiler
/// </summary>
/// <param name="varDefListNode">The varDefListOp subtree</param>
/// <param name="varRefMap">ref counts for each referenced var</param>
- /// <returns>mapping from Var->replacement xpressions</returns>
+ /// <returns>mapping from Var->replacement expressions</returns>
internal Dictionary<Var, Node> GetVarMap(Node varDefListNode, Dictionary<Var, int> varRefMap)
{
VarDefListOp varDefListOp = (VarDefListOp)varDefListNode.Op;
@@ -413,7 +413,7 @@ namespace System.Data.Query.PlanCompiler
private readonly VarRemapper m_remapper;
private readonly Dictionary<Node, Node> m_suppressions;
private readonly VarVec m_remappedVars;
- private bool m_projectionPrunningRequired = false;
+ private bool m_projectionPruningRequired = false;
private bool m_reapplyNullabilityRules = false;
private Stack<Node> m_relOpAncestors = new Stack<Node>();
#if DEBUG
@@ -488,7 +488,7 @@ namespace System.Data.Query.PlanCompiler
/// Callback function to invoke *after* rules are applied
/// Recomputes the node info, if this node has changed
/// If the rule is among the rules after which projection pruning may be beneficial,
/// m_projectionPrunningRequired is set to true.
/// If the rule is among the rules after which reapplying the nullability rules may be beneficial,
/// m_reapplyNullabilityRules is set to true.
/// </summary>
@@ -502,9 +502,9 @@ namespace System.Data.Query.PlanCompiler
appliedRules.Append(rule.MethodName);
appliedRules.AppendLine();
#endif
- if (!this.m_projectionPrunningRequired && TransformationRules.RulesRequiringProjectionPruning.Contains(rule))
+ if (!this.m_projectionPruningRequired && TransformationRules.RulesRequiringProjectionPruning.Contains(rule))
{
- this.m_projectionPrunningRequired = true;
+ this.m_projectionPruningRequired = true;
}
if (!this.m_reapplyNullabilityRules && TransformationRules.RulesRequiringNullabilityRulesToBeReapplied.Contains(rule))
{
@@ -609,7 +609,7 @@ namespace System.Data.Query.PlanCompiler
/// <summary>
/// A lookup table built only from rules that rely on nullability of vars and other rules
- /// that may be able to perform simplificatios if these have been applied.
+ /// that may be able to perform simplification if these have been applied.
/// The lookup table is an array indexed by OpType and each entry has a list of rules.
/// </summary>
internal static readonly ReadOnlyCollection<ReadOnlyCollection<InternalTrees.Rule>> NullabilityRulesTable = BuildLookupTableForRules(NullabilityRules);
@@ -778,14 +778,14 @@ namespace System.Data.Query.PlanCompiler
// If any rule has been applied after which reapplying nullability rules may be useful,
// reapply nullability rules.
- bool projectionPrunningRequired;
- if (Process(compilerState, rulesTable, out projectionPrunningRequired))
+ bool projectionPruningRequired;
+ if (Process(compilerState, rulesTable, out projectionPruningRequired))
{
- bool projectionPrunningRequired2;
- Process(compilerState, NullabilityRulesTable, out projectionPrunningRequired2);
- projectionPrunningRequired = projectionPrunningRequired || projectionPrunningRequired2;
+ bool projectionPruningRequired2;
+ Process(compilerState, NullabilityRulesTable, out projectionPruningRequired2);
+ projectionPruningRequired = projectionPruningRequired || projectionPruningRequired2;
}
- return projectionPrunningRequired;
+ return projectionPruningRequired;
}
/// <summary>
@@ -800,7 +800,7 @@ namespace System.Data.Query.PlanCompiler
RuleProcessor ruleProcessor = new RuleProcessor();
TransformationRulesContext context = new TransformationRulesContext(compilerState);
compilerState.Command.Root = ruleProcessor.ApplyRulesToSubtree(context, rulesTable, compilerState.Command.Root);
- projectionPruningRequired = context.ProjectionPrunningRequired;
+ projectionPruningRequired = context.ProjectionPruningRequired;
return context.ReapplyNullabilityRules;
}
}
@@ -1017,7 +1017,7 @@ namespace System.Data.Query.PlanCompiler
/// WHEN W1 THEN T1
/// WHEN W2 THEN T2 ...
/// ELSE (CASE
- /// WHEN WN1 THEN TN1, …
+ /// WHEN WN1 THEN TN1,
/// ELSE E)
///
/// Is transformed into
@@ -1096,7 +1096,7 @@ namespace System.Data.Query.PlanCompiler
// Make sure that the terminal character of the pattern is a '%' character. Also
// ensure that this character does not occur anywhere else. And finally, ensure
- // that the pattern is atmost one character longer than the string itself
+ // that the pattern is at most one character longer than the string itself
int wildCardIndex = pattern.IndexOf('%');
if ((wildCardIndex == -1) ||
(wildCardIndex != pattern.Length - 1) ||
@@ -2189,7 +2189,7 @@ namespace System.Data.Query.PlanCompiler
NodeInfo nodeInfo = context.Command.GetNodeInfo(n);
// We cannot eliminate this node because it can break other rules,
- // e.g. ProcessApplyOverAnything which relies on existance of external refs to substitute
+ // e.g. ProcessApplyOverAnything which relies on existence of external refs to substitute
// CrossApply(x, y) => CrossJoin(x, y). See SQLBU #481719.
if (!nodeInfo.ExternalReferences.IsEmpty)
{
@@ -2283,7 +2283,7 @@ namespace System.Data.Query.PlanCompiler
// Note: Even if we don't have any local var definitions left, we should not remove
// this project yet because:
- // (1) this project node may be prunning out some outputs;
+ // (1) this project node may be pruning out some outputs;
// (2) the rule Rule_ProjectWithNoLocalDefs, would do that later anyway.
// Create a new vardeflist node, and set that as Child1 for the projectOp
@@ -2634,7 +2634,7 @@ namespace System.Data.Query.PlanCompiler
/// <param name="context">RuleProcessing context</param>
/// <param name="applyNode">The ApplyOp subtree</param>
/// <param name="newNode">transformed subtree</param>
- /// <returns>Transfomation status</returns>
+ /// <returns>Transformation status</returns>
static bool ProcessCrossApplyOverProject(RuleProcessingContext context, Node applyNode, out Node newNode)
{
newNode = applyNode;
@@ -2699,7 +2699,7 @@ namespace System.Data.Query.PlanCompiler
/// <param name="context">RuleProcessing context</param>
/// <param name="applyNode">The ApplyOp subtree</param>
/// <param name="newNode">transformed subtree</param>
- /// <returns>Transfomation status</returns>
+ /// <returns>Transformation status</returns>
static bool ProcessOuterApplyOverProject(RuleProcessingContext context, Node applyNode, out Node newNode)
{
newNode = applyNode;
@@ -2737,7 +2737,7 @@ namespace System.Data.Query.PlanCompiler
//
// Dev10 #480443: If any of the definitions changes we need to recompute the node info.
- bool anyVarDefChagned = false;
+ bool anyVarDefChanged = false;
foreach (Node varDefNode in varDefListNode.Children)
{
PlanCompiler.Assert(varDefNode.Op.OpType == OpType.VarDef, "Expected VarDefOp. Found " + varDefNode.Op.OpType + " instead");
@@ -2772,12 +2772,12 @@ namespace System.Data.Query.PlanCompiler
}
varDefNode.Child0 = currentDefinition;
command.RecomputeNodeInfo(varDefNode);
- anyVarDefChagned = true;
+ anyVarDefChanged = true;
}
}
// Recompute node info if needed
- if (anyVarDefChagned)
+ if (anyVarDefChanged)
{
command.RecomputeNodeInfo(varDefListNode);
}
@@ -3002,7 +3002,7 @@ namespace System.Data.Query.PlanCompiler
}
/// <summary>
- /// A visitor that calculates the number of output columns for a subree
+ /// A visitor that calculates the number of output columns for a subtree
/// with a given root
/// </summary>
internal class OutputCountVisitor : BasicOpVisitorOfT<int>
@@ -3015,7 +3015,7 @@ namespace System.Data.Query.PlanCompiler
#region Public Methods
/// <summary>
- /// Calculates the number of output columns for the subree
+ /// Calculates the number of output columns for the subtree
/// rooted at the given node
/// </summary>
/// <param name="node"></param>
@@ -3178,7 +3178,7 @@ namespace System.Data.Query.PlanCompiler
/// <summary>
/// Public entry point.
- /// Remaps the subree rooted at the given tree
+ /// Remaps the subtree rooted at the given tree
/// </summary>
/// <param name="root"></param>
/// <param name="command"></param>
@@ -3964,7 +3964,7 @@ namespace System.Data.Query.PlanCompiler
/// of agg1, agg2, .. aggm, such that the references to c1, ... ck are
/// replaced by their definitions.
///
- /// We only do this if each c1, ..ck is refereneced (in aggregates) at most once or it is a constant.
+ /// We only do this if each c1, ..ck is referenced (in aggregates) at most once or it is a constant.
/// </summary>
/// <param name="context">Rule processing context</param>
/// <param name="projectNode">Current ProjectOp node</param>
@@ -4038,7 +4038,7 @@ namespace System.Data.Query.PlanCompiler
}
/// <summary>
- /// Replaces each occurance of the given vars with their definitions.
+ /// Replaces each occurrence of the given vars with their definitions.
/// </summary>
internal class VarRefReplacer : BasicOpVisitorOfNode
{
@@ -4053,7 +4053,7 @@ namespace System.Data.Query.PlanCompiler
/// <summary>
/// "Public" entry point. In the subtree rooted at the given root,
- /// replace each occurance of the given vars with their definitions,
+ /// replace each occurrence of the given vars with their definitions,
/// where each key-value pair in the dictionary is a var-definition pair.
/// </summary>
/// <param name="varReplacementTable"></param>
@@ -4110,7 +4110,7 @@ namespace System.Data.Query.PlanCompiler
/// <summary>
/// Public entry point. Returns true if at least one of the given vars occurs more than
- /// once in the subree rooted at the given root.
+ /// once in the subtree rooted at the given root.
/// </summary>
/// <param name="varVec"></param>
/// <param name="root"></param>
@@ -4376,7 +4376,7 @@ namespace System.Data.Query.PlanCompiler
#region ConstrainedSortOpOverEmptySet
internal static readonly SimpleRule Rule_ConstrainedSortOpOverEmptySet = new SimpleRule(OpType.ConstrainedSort, ProcessConstrainedSortOpOverEmptySet);
/// <summary>
- /// If the ConstrainedSortOp's input is guaranteed to produce no rows, remove the ConstrainedSortOp completly:
+ /// If the ConstrainedSortOp's input is guaranteed to produce no rows, remove the ConstrainedSortOp completely:
/// CSort(EmptySet) => EmptySet
/// </summary>
/// <param name="context">Rule processing context</param>
@@ -4387,7 +4387,7 @@ namespace System.Data.Query.PlanCompiler
{
ExtendedNodeInfo nodeInfo = ((TransformationRulesContext)context).Command.GetExtendedNodeInfo(n.Child0);
- //If the input has no rows, remove the ConstraintSortOp node completly
+ //If the input has no rows, remove the ConstraintSortOp node completely
if (nodeInfo.MaxRows == RowCount.Zero)
{
newNode = n.Child0;
@@ -488,7 +488,7 @@ namespace System.Data.Query.PlanCompiler
/// Recomputes the node info, if this node has changed
/// If the rule is among the rules after which projection pruning may be beneficial,
- /// m_projectionPrunningRequired is set to true.
+ /// m_projectionPruningRequired is set to true.
/// If the rule is among the rules after which reapplying the nullability rules may be beneficial,
/// m_reapplyNullabilityRules is set to true.